**discogui**

:Date: |today|
:PDF: `discogui.pdf <discogui.pdf>`_

Contents:

.. toctree::
    :maxdepth: 2

    readme
    usage
    api
    related
    dev

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

